<?php

namespace Drupal\a12s_page_context;

/**
 * Represents a record from the database.
 */
class Record {

  protected int $id;

  protected string $config_id;

  protected string $plugin_id;

  protected string $key;

  protected array $_data = [];

  protected array $_settings = [];

  /**
   * This setter takes care of deserializing stored values.
   *
   * @param string $name
   *   THe property name.
   * @param mixed $value
   *   The value to set.
   *
   * @return void
   */
  public function __set(string $name, mixed $value): void {
    if (in_array($name, ['data', 'settings'])) {
      $this->{'_' . $name} = !empty($value) ? unserialize($value) : [];
    }
  }

  /**
   * Get the record ID.
   *
   * @return int
   */
  public function getId(): int {
    return $this->id;
  }

  /**
   * Get the page context form ID.
   *
   * @return string
   */
  public function getConfigId(): string {
    return $this->config_id;
  }

  /**
   * Get the plugin ID.
   *
   * @return string
   */
  public function getPluginId(): string {
    return $this->plugin_id;
  }

  /**
   * Get the storage key.
   *
   * @return string
   */
  public function getKey(): string {
    return $this->key;
  }

  /**
   * Get the record data.
   *
   * @return array
   */
  public function getData(): array {
    return $this->_data;
  }

  /**
   * Get the record settings.
   *
   * @return array
   */
  public function getSettings(): array {
    return $this->_settings;
  }

}
